package com.qmth.distributed.print.business.util;

import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.io.*;
import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @Description: 转换工具类
 * @Author: CaoZixuan
 * @Date: 2021-04-14
 */

@Component
public class ConvertUtil {

    @Resource
    RedisTemplate<String, Object> redisTemplate;

    // inputStream转outputStream
    public static ByteArrayOutputStream parse(final InputStream in) throws Exception {
        final ByteArrayOutputStream swapStream = new ByteArrayOutputStream();
        int ch;
        while ((ch = in.read()) != -1) {
            swapStream.write(ch);
        }
        return swapStream;
    }

    // outputStream转inputStream
    public static ByteArrayInputStream parse(final OutputStream out) {
        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        baos = (ByteArrayOutputStream) out;
        return new ByteArrayInputStream(baos.toByteArray());
    }

    public static void inputStream2File (InputStream is, File file) throws IOException {
        OutputStream os = null;
        try {
            os = new FileOutputStream(file);
            int len = 0;
            byte[] buffer = new byte[8192];

            while ((len = is.read(buffer)) != -1) {
                os.write(buffer, 0, len);
            }
        } finally {
            os.close();
            is.close();
        }
    }

    /**
     * 转换，解析时间
     * @param date 日期(考试日期，必须是同一天     example: 2021-04-13)
     * @param time 时间(考试时间，必须使用‘-’隔开  example: 18:00-20:00)
     * @return 开始时间和结束时间键值对("startTime":1618308000000 ,"endTime":1618315200000)
     */
    public static Map<String,Object> analyzeStartAndEndTime(String date,String time){
        time = time.replaceAll(" ",""); // 去掉所有空格
        String[] arr = time.split("-");
        if (arr.length != 2){
            // 不能使用'-'拆分成两个时间的报错
            System.out.println("提供的时间格式异常 时间 : " + time);
        }
        String startTimeStr = date + " " + arr[0];
        String endTimeStr = date + " " + arr[1];
        long startTime = DateDisposeUtils.parseDate(startTimeStr).getTime();
        long endTime = DateDisposeUtils.parseDate(endTimeStr).getTime();
        if (startTime >= endTime){
            System.out.println("开始时间要小于结束时间 时间： " + time);
        }

        System.out.println("开始时间 ： " + startTimeStr + " 结束时间 ： " + endTimeStr);
        System.out.println("开始时间 ： " + startTime + " 结束时间 ： " + endTime);
        System.out.println(new Date().getTime());

        Map<String,Object> timeMap = new HashMap<>();
        timeMap.put("startTime",startTime);
        timeMap.put("endTime",endTime);
        return timeMap;
    }

    /**
     * 获取递增的序列号
     *
     * @param prefix 生成序列号的前缀
     * @return
     */
    public String getIncre(String prefix,String model) {
        //序列号前缀加特定标识，如系统模块名之类的 防止重复
        String key = model + "-" + prefix;
        String increResult = null;
        try {
            //如果该key不存在 会自动创建，值为第二个参数delta
            //最终调用的还是jedis的incrBy(byte[] key, long value)方法
            Long increNum = redisTemplate.opsForValue().increment(key, 1);
            //不足补位
            increResult = prefix + String.format("%1$06d", increNum);
        } catch (Exception e) {
            System.out.println("获取序列号失败");
            /*这里可以根据需求手动生成一个不重复的单号，
             * */
        }
        return increResult;
    }
}
